@@ -1,9 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::EOL; # git description: 0.16-12-g77240fb
+package Dist::Zilla::Plugin::Test::EOL; # git description: 0.17-10-gd9ed619
 # ABSTRACT: Author tests making sure correct line endings are used
 # KEYWORDS: plugin test testing author development whitespace newline linefeed formatting
-$Dist::Zilla::Plugin::Test::EOL::VERSION = '0.17';
+
+our $VERSION = '0.18';
+
 use Moose;
 use Path::Tiny;
 use Sub::Exporter::ForMethods 'method_installer';
@@ -194,7 +196,7 @@ Dist::Zilla::Plugin::Test::EOL - Author tests making sure correct line endings a
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -306,7 +308,7 @@ ___[ __TEST__ ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
+# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
 
 use Test::More 0.88;
 use Test::EOL;
